@@ -2,12 +2,8 @@ import codecs
 import os
 import sys
 import json
-from .constant import false, MIME_TYPE_JSON, CHARSET, CHARSET_UTF8
-from .cgi_response import respond, STATUS_BAD_REQUEST
-
-# cgi request header environment variables and values
-CONTENT_LENGTH = "CONTENT_LENGTH"
-CONTENT_TYPE = "CONTENT_TYPE"
+from .constant import false, MIME_TYPE_JSON, CHARSET, CHARSET_UTF8, STATUS_BAD_REQUEST, CONTENT_TYPE, CONTENT_LENGTH
+from .cgi_response import respond
 
 class CgiRequest:
 
